==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/ts/File_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation>Outils de fichier</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation>Outils de fichier</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location line="+63"/>
        <source>Format:</source>
        <translation>Format :</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Overwrite File?</source>
        <translatorcomment>--exact match--
--file: Save_fr.ts--
Remplacer le fichier?
Le fichier existe:
&quot;%1&quot;
Remplacer?</translatorcomment>
        <translation>Remplacer le fichier?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Le fichier &apos;%1&apos; existe déjà. Est-ce que vous souhaitez le remplacer?</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--exact match--
--file: Save_fr.ts--
Le fichier &quot;%1&quot; existe déjà. Est-ce que vous souhaitez le remplacer?</translatorcomment>
        <translation type="obsolete">Le fichier &quot;%1&quot; existe déjà. Est-ce que vous souhaitez le remplacer?</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/ts/File_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation>Outils de fichier</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation>Outils de fichier</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location line="+91"/>
        <location line="+69"/>
        <source>Format:</source>
        <translation>Format :</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Overwrite File?</source>
        <translatorcomment>--exact match--
--file: Save_fr.ts--
Remplacer le fichier?
Le fichier existe:
&quot;%1&quot;
Remplacer?</translatorcomment>
        <translation>Remplacer le fichier?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Le fichier &apos;%1&apos; existe déjà. Est-ce que vous souhaitez le remplacer?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All Files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--exact match--
--file: Save_fr.ts--
Le fichier &quot;%1&quot; existe déjà. Est-ce que vous souhaitez le remplacer?</translatorcomment>
        <translation type="obsolete">Le fichier &quot;%1&quot; existe déjà. Est-ce que vous souhaitez le remplacer?</translation>
    </message>
</context>
</TS>
